@@ -589,6 +589,9 @@ class Instance(NamedTuple):
     brevity: str
     """Brevity style of this instance. Supported values are: C{concise}, C{adaptive}, C{verbose}."""
 
+    creativity: Optional[float]
+    """Optional creativity level, specified as a number between 0 and 1."""
+
     job_title: str
     """Assigned job title."""
 
