@@ -47,7 +47,8 @@ def make_flask_server(
     rest_port: int,
     rest_url: str,
     rest_methods: list[str] = None,
-    ssl_ctx_data: Optional[SSLContextData] = None
+    ssl_ctx_data: Optional[SSLContextData] = None,
+    skip_unknown_fields: bool = True
 ) -> BaseWSGIServer:
     """
     Creates a Flask-based HTTP server to handle requests for the HumatronWorker.
@@ -71,6 +72,8 @@ def make_flask_server(
         The HTTP methods allowed for the endpoint (defaults to ['POST']).
     @param ssl_ctx_data :
         SSL context data for enabling HTTPS communication. If None, HTTP is used.
+    @param skip_unknown_fields :
+        A flag that determines whether unknown fields should be skipped or trigger an error.
 
     @return:
         A WSGI server instance ready to handle incoming HTTP requests.
@@ -99,7 +102,7 @@ def make_flask_server(
                 abort(make_response(jsonify({}), 401))
 
             # Process the request using the HumatronWorker
-            resp_spec = worker.process_request(Request.from_dict(request.json))
+            resp_spec = worker.process_request(Request.from_dict(request.json, skip_unknown_fields))
 
             # Prepare the response object
             resp_flask = flask.make_response(resp_spec.to_dict()) if resp_spec else flask.jsonify({})
